@@ -8,60 +8,62 @@
 #include <string.h>
 #include <rime_api.h>
 
-void print_status(RimeStatus *status) {
-  printf("schema: %s / %s\n",
-         status->schema_id, status->schema_name);
+void print_status(RimeStatus* status) {
+  printf("schema: %s / %s\n", status->schema_id, status->schema_name);
   printf("status: ");
-  if (status->is_disabled) printf("disabled ");
-  if (status->is_composing) printf("composing ");
-  if (status->is_ascii_mode) printf("ascii ");
-  if (status->is_full_shape) printf("full_shape ");
-  if (status->is_simplified) printf("simplified ");
+  if (status->is_disabled)
+    printf("disabled ");
+  if (status->is_composing)
+    printf("composing ");
+  if (status->is_ascii_mode)
+    printf("ascii ");
+  if (status->is_full_shape)
+    printf("full_shape ");
+  if (status->is_simplified)
+    printf("simplified ");
   printf("\n");
 }
 
-void print_composition(RimeComposition *composition) {
-  const char *preedit = composition->preedit;
-  if (!preedit) return;
+void print_composition(RimeComposition* composition) {
+  const char* preedit = composition->preedit;
+  if (!preedit)
+    return;
   size_t len = strlen(preedit);
   size_t start = composition->sel_start;
   size_t end = composition->sel_end;
-  //size_t cursor = composition->cursor_pos;
+  // size_t cursor = composition->cursor_pos;
   for (size_t i = 0; i <= len; ++i) {
     if (start < end) {
-      if (i == start) putchar('[');
-      else if (i == end) putchar(']');
+      if (i == start)
+        putchar('[');
+      else if (i == end)
+        putchar(']');
     }
-    //if (i == cursor) putchar('|');
+    // if (i == cursor) putchar('|');
     if (i < len)
-        putchar(preedit[i]);
+      putchar(preedit[i]);
   }
   printf("\n");
 }
 
-void print_menu(RimeMenu *menu) {
-  if (menu->num_candidates == 0) return;
-  printf("page: %d%c (of size %d)\n",
-         menu->page_no + 1,
-         menu->is_last_page ? '$' : ' ',
-         menu->page_size);
+void print_menu(RimeMenu* menu) {
+  if (menu->num_candidates == 0)
+    return;
+  printf("page: %d%c (of size %d)\n", menu->page_no + 1,
+         menu->is_last_page ? '$' : ' ', menu->page_size);
   for (int i = 0; i < menu->num_candidates; ++i) {
     bool highlighted = i == menu->highlighted_candidate_index;
-    printf("%d. %c%s%c%s\n",
-           i + 1,
-           highlighted ? '[' : ' ',
-           menu->candidates[i].text,
-           highlighted ? ']' : ' ',
+    printf("%d. %c%s%c%s\n", i + 1, highlighted ? '[' : ' ',
+           menu->candidates[i].text, highlighted ? ']' : ' ',
            menu->candidates[i].comment ? menu->candidates[i].comment : "");
   }
 }
 
-void print_context(RimeContext *context) {
+void print_context(RimeContext* context) {
   if (context->composition.length > 0) {
     print_composition(&context->composition);
     print_menu(&context->menu);
-  }
-  else {
+  } else {
     printf("(not composing)\n");
   }
 }
@@ -96,8 +98,8 @@ bool execute_special_command(const char* line, RimeSessionId session_id) {
     if (rime->get_schema_list(&list)) {
       printf("schema list:\n");
       for (size_t i = 0; i < list.size; ++i) {
-        printf("%lu. %s [%s]\n", (i + 1),
-               list.list[i].name, list.list[i].schema_id);
+        printf("%lu. %s [%s]\n", (i + 1), list.list[i].name,
+               list.list[i].schema_id);
       }
       rime->free_schema_list(&list);
     }
@@ -126,7 +128,7 @@ void on_message(void* context_object,
 
 static RIME_MODULE_LIST(sample_modules, "default", "sample");
 
-int main(int argc, char *argv[]) {
+int main(int argc, char* argv[]) {
   RimeApi* rime = rime_get_api();
 
   RIME_STRUCT(RimeTraits, traits);
@@ -152,7 +154,7 @@ int main(int argc, char *argv[]) {
   const int kMaxLength = 99;
   char line[kMaxLength + 1] = {0};
   while (fgets(line, kMaxLength, stdin) != NULL) {
-    for (char *p = line; *p; ++p) {
+    for (char* p = line; *p; ++p) {
       if (*p == '\r' || *p == '\n') {
         *p = '\0';
         break;
@@ -164,8 +166,7 @@ int main(int argc, char *argv[]) {
       continue;
     if (!rime->simulate_key_sequence(session_id, line)) {
       fprintf(stderr, "Error processing key sequence: %s\n", line);
-    }
-    else {
+    } else {
       print(session_id);
     }
   }
