@@ -67,24 +67,24 @@ class Prism : public MappedFile {
  public:
   using Match = Darts::DoubleArray::result_pair_type;
 
-  RIME_API explicit Prism(const path& file_path);
+  RIME_DLL explicit Prism(const path& file_path);
 
-  RIME_API bool Load();
-  RIME_API bool Save();
-  RIME_API bool Build(const Syllabary& syllabary,
+  RIME_DLL bool Load();
+  RIME_DLL bool Save();
+  RIME_DLL bool Build(const Syllabary& syllabary,
                       const Script* script = nullptr,
                       uint32_t dict_file_checksum = 0,
                       uint32_t schema_file_checksum = 0);
 
-  RIME_API bool HasKey(const string& key);
-  RIME_API bool GetValue(const string& key, int* value) const;
-  RIME_API void CommonPrefixSearch(const string& key, vector<Match>* result);
-  RIME_API void ExpandSearch(const string& key,
+  RIME_DLL bool HasKey(const string& key);
+  RIME_DLL bool GetValue(const string& key, int* value) const;
+  RIME_DLL void CommonPrefixSearch(const string& key, vector<Match>* result);
+  RIME_DLL void ExpandSearch(const string& key,
                              vector<Match>* result,
                              size_t limit);
   SpellingAccessor QuerySpelling(SyllableId spelling_id);
 
-  RIME_API size_t array_size() const;
+  RIME_DLL size_t array_size() const;
 
   uint32_t dict_file_checksum() const;
   uint32_t schema_file_checksum() const;
