@@ -12,22 +12,49 @@
 #include <rime/key_event.h>
 #include <rime/processor.h>
 #include <rime/algo/algebra.h>
+#include <rime/gear/key_binding_processor.h>
 
 namespace rime {
 
-class ChordComposer : public Processor {
+using Chord = set<int>;
+
+struct ChordingState {
+  Chord pressed_keys;
+  Chord recognized_chord;
+
+  bool IsPressed(int ch) const {
+    return pressed_keys.find(ch) != pressed_keys.end();
+  }
+
+  bool PressKey(int ch) { return pressed_keys.insert(ch).second; }
+
+  bool ReleaseKey(int ch) { return pressed_keys.erase(ch) != 0; }
+
+  bool AddKeyToChord(int ch) { return recognized_chord.insert(ch).second; }
+
+  void Clear() {
+    pressed_keys.clear();
+    recognized_chord.clear();
+  }
+};
+
+class ChordComposer : public Processor,
+                      public KeyBindingProcessor<ChordComposer> {
  public:
   ChordComposer(const Ticket& ticket);
   ~ChordComposer();
 
   virtual ProcessResult ProcessKeyEvent(const KeyEvent& key_event);
 
+  Handler CommitRawInput;
+
  protected:
+  bool FinishChordConditionIsMet() const;
   ProcessResult ProcessChordingKey(const KeyEvent& key_event);
   ProcessResult ProcessFunctionKey(const KeyEvent& key_event);
-  string SerializeChord();
-  void UpdateChord();
-  void FinishChord();
+  string SerializeChord(const Chord& chord);
+  void UpdateChord(const Chord& chord);
+  void FinishChord(const Chord& chord);
   void ClearChord();
   bool DeleteLastSyllable();
   void OnContextUpdate(Context* ctx);
@@ -41,9 +68,11 @@ class ChordComposer : public Processor {
   bool use_control_ = false;
   bool use_alt_ = false;
   bool use_shift_ = false;
+  bool use_super_ = false;
+  bool use_caps_ = false;
+  bool finish_chord_on_first_key_release_ = false;
 
-  set<int> pressed_;
-  set<int> chord_;
+  ChordingState state_;
   bool editing_chord_ = false;
   bool sending_chord_ = false;
   bool composing_ = false;
