@@ -3,7 +3,6 @@
 
 #include <rime/common.h>
 #include <rime/component.h>
-#include <rime/dict/vocabulary.h>
 
 namespace rime {
 
@@ -17,12 +16,13 @@ class Grammar : public Class<Grammar, Config*> {
                        bool is_rear) = 0;
 
   inline static double Evaluate(const string& context,
-                                const DictEntry& entry,
+                                const string& entry_text,
+                                double entry_weight,
                                 bool is_rear,
                                 Grammar* grammar) {
-    const double kPenalty = -18.420680743952367; // log(1e-8)
-    return entry.weight +
-        (grammar ? grammar->Query(context, entry.text, is_rear) : kPenalty);
+    const double kPenalty = -18.420680743952367;  // log(1e-8)
+    return entry_weight +
+           (grammar ? grammar->Query(context, entry_text, is_rear) : kPenalty);
   }
 };
 
