@@ -5,19 +5,17 @@
 // 2012-02-26 GONG Chen <chen.sst@gmail.com>
 //
 #include <boost/algorithm/string.hpp>
-#include <boost/filesystem.hpp>
 #include <rime/config.h>
 #include <rime/deployer.h>
 #include <rime/signature.h>
 #include <rime/lever/custom_settings.h>
 
-namespace fs = boost::filesystem;
-
 namespace rime {
 
 static string remove_suffix(const string& input, const string& suffix) {
-  return boost::ends_with(input, suffix) ?
-      input.substr(0, input.length() - suffix.length()) : input;
+  return boost::ends_with(input, suffix)
+             ? input.substr(0, input.length() - suffix.length())
+             : input;
 }
 
 static string custom_config_file(const string& config_id) {
@@ -27,22 +25,19 @@ static string custom_config_file(const string& config_id) {
 CustomSettings::CustomSettings(Deployer* deployer,
                                const string& config_id,
                                const string& generator_id)
-    : deployer_(deployer),
-      config_id_(config_id),
-      generator_id_(generator_id) {
-}
+    : deployer_(deployer), config_id_(config_id), generator_id_(generator_id) {}
 
 bool CustomSettings::Load() {
-  fs::path config_path = fs::path(deployer_->staging_dir) / (config_id_ + ".yaml");
-  if (!config_.LoadFromFile(config_path.string())) {
-    config_path = fs::path(deployer_->prebuilt_data_dir) / (config_id_ + ".yaml");
-    if (!config_.LoadFromFile(config_path.string())) {
+  path config_path = deployer_->staging_dir / (config_id_ + ".yaml");
+  if (!config_.LoadFromFile(config_path)) {
+    config_path = deployer_->prebuilt_data_dir / (config_id_ + ".yaml");
+    if (!config_.LoadFromFile(config_path)) {
       LOG(WARNING) << "cannot find '" << config_id_ << ".yaml'.";
     }
   }
-  fs::path custom_config_path =
-      fs::path(deployer_->user_data_dir) / custom_config_file(config_id_);
-  if (!custom_config_.LoadFromFile(custom_config_path.string())) {
+  path custom_config_path =
+      deployer_->user_data_dir / custom_config_file(config_id_);
+  if (!custom_config_.LoadFromFile(custom_config_path)) {
     return false;
   }
   modified_ = false;
@@ -54,9 +49,9 @@ bool CustomSettings::Save() {
     return false;
   Signature signature(generator_id_, "customization");
   signature.Sign(&custom_config_, deployer_);
-  fs::path custom_config_path(deployer_->user_data_dir);
+  path custom_config_path(deployer_->user_data_dir);
   custom_config_path /= custom_config_file(config_id_);
-  custom_config_.SaveToFile(custom_config_path.string());
+  custom_config_.SaveToFile(custom_config_path);
   modified_ = false;
   return true;
 }
@@ -73,8 +68,7 @@ an<ConfigMap> CustomSettings::GetMap(const string& key) {
   return config_.GetMap(key);
 }
 
-bool CustomSettings::Customize(const string& key,
-                               const an<ConfigItem>& item) {
+bool CustomSettings::Customize(const string& key, const an<ConfigItem>& item) {
   auto patch = custom_config_.GetMap("patch");
   if (!patch) {
     patch = New<ConfigMap>();
@@ -88,10 +82,10 @@ bool CustomSettings::Customize(const string& key,
 }
 
 bool CustomSettings::IsFirstRun() {
-  fs::path custom_config_path(deployer_->user_data_dir);
-  custom_config_path /= custom_config_file(config_id_);
+  path custom_config_path =
+      deployer_->user_data_dir / custom_config_file(config_id_);
   Config config;
-  if (!config.LoadFromFile(custom_config_path.string()))
+  if (!config.LoadFromFile(custom_config_path))
     return true;
   return !config.GetMap("customization");
 }
