@@ -8,7 +8,6 @@
 #include <rime/algo/syllabifier.h>
 #include <rime/dict/table.h>
 
-
 class RimeTableTest : public ::testing::Test {
  public:
   virtual void SetUp() {
@@ -23,9 +22,8 @@ class RimeTableTest : public ::testing::Test {
     }
     table_->Load();
   }
-  virtual void TearDown() {
-    table_->Close();
-  }
+  virtual void TearDown() { table_->Close(); }
+
  protected:
   static const int total_num_entries = 8;
 
@@ -89,7 +87,7 @@ void RimeTableTest::PrepareSampleVocabulary(rime::Syllabary& syll,
   d->code.resize(3);
   d->code.push_back(2);
   d->code.push_back(1);
-  d->text  = "yi-er-san-er-yi";
+  d->text = "yi-er-san-er-yi";
   (*lv4)[-1].entries.push_back(d);
 }
 
